@@ -1,7 +1,20 @@
 # -*- coding: utf-8 -*-
-from parser import UrlRequest
+import requests
 import re
 
+def get_request(url, params=None):
+    return requests.get(url, params=params, headers={
+        'User-Agent': 'Mozilla/5.0 (X11; U; Linux i686; ru; rv:1.9.1.8) Gecko/20100214 Linux Mint/8 (Helena) Firefox/3.5.8',
+        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
+        'Accept-Language': 'ru,en-us;q=0.7,en;q=0.3',
+        'Accept-Encoding': 'deflate',
+        'Accept-Charset': 'windows-1251,utf-8;q=0.7,*;q=0.7',
+        'Keep-Alive': '300',
+        'Connection': 'keep-alive',
+        'Referer': 'http://www.kinopoisk.ru/',
+        'Cookie': 'users_info[check_sh_bool]=none; search_last_date=2010-02-19; search_last_month=2010-02;                                        PHPSESSID=b6df76a958983da150476d9cfa0aab18',
+    })
+
 class Manager(object):
 
     kinopoisk_object = None
@@ -9,10 +22,10 @@ class Manager(object):
 
     def search(self, query):
         url, params = self.get_url_with_params(query)
-        request = UrlRequest(url, params)
-        content = request.read()
+        response = get_request(url, params=params)
+        content = response.content.decode('windows-1251', 'ignore')
         # request is redirected to main page of object
-        if request.is_redirected:
+        if len(response.history):
             instance = self.kinopoisk_object()
             instance.parse('main_page', content)
             return [instance]
@@ -22,12 +35,12 @@ class Manager(object):
                 return []
             content_results = content[content.find('<div class="search_results">'):content.find('<div style="height: 40px"></div>')]
             if content_results:
-                from BeautifulSoup import BeautifulSoup # import here for correct installing vi pip
+                from BeautifulSoup import BeautifulSoup # import here for successful installing via pip
                 soup_results = BeautifulSoup(content_results)
                 # <div class="element width_2">
                 results = soup_results.findAll('div', attrs={'class': re.compile('element')})
                 if not results:
-                    raise ValueError('No objects found in search results by request "%s"' % request.url)
+                    raise ValueError('No objects found in search results by request "%s"' % response.url)
                 instances = []
                 for result in results:
                     instance = self.kinopoisk_object()
@@ -36,7 +49,7 @@ class Manager(object):
                         instances += [instance]
                 return instances
 
-            raise ValueError('Unknown html layout found by request "%s"' % request.url)
+            raise ValueError('Unknown html layout found by request "%s"' % response.url)
 
     def get_url_with_params(self, query):
         return ('http://www.kinopoisk.ru/index.php', {'kp_query': query})
